BashPrgHash

Struct BashPrgHash 

pub struct BashPrgHash<const RATE: usize, const CAPACITY: usize> { /* private fields */ }
bash-prg-hash hasher generic over rate and capacity.

Generic Parameters

Only the following combinations of rate and capacity with the resulting security level are supported:

Rate, bytesCapacitySecurity level, bitsVariant
1601128BashPrgHash1281
1282128BashPrgHash1282
1441192BashPrgHash1921
962192BashPrgHash1922
1281256BashPrgHash2561
642256BashPrgHash2562

Trying to initialize hasher state with a different pair of parameters will result in a compilation error.

Users are recommended to use type aliases referenced in the last column instead of using this type directly.