pub struct BashPrgHash<const RATE: usize, const CAPACITY: usize> { /* private fields */ }Expand description
bash-prg-hash hasher generic over rate and capacity.
Generic Parameters
Only the following combinations of rate and capacity with the resulting security level are supported:
| Rate, bytes | Capacity | Security level, bits | Variant |
|---|---|---|---|
| 160 | 1 | 128 | BashPrgHash1281 |
| 128 | 2 | 128 | BashPrgHash1282 |
| 144 | 1 | 192 | BashPrgHash1921 |
| 96 | 2 | 192 | BashPrgHash1922 |
| 128 | 1 | 256 | BashPrgHash2561 |
| 64 | 2 | 256 | BashPrgHash2562 |
Trying to initialize hasher state with a different pair of parameters will result in a compilation error.
Users are recommended to use type aliases referenced in the last column instead of using this type directly.